@@ -8,7 +8,7 @@ use constant MAX_RAND => 2 ** 32;
 use Carp;
 use File::Spec;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 ## CLASS METHODS
 sub new {
@@ -93,7 +93,7 @@ sub _io_spec {
     my $private_method = "_$io";
 
     if ( defined $spec ) {
-        
+
         my $io_type = $private_method . '_type';
         $self->$io_type        = ref $spec || 'SCALAR';
         $self->{$io}           = $spec;
@@ -203,7 +203,7 @@ sub stringify {
 
 sub run {
     my ($self) = @_;
-    
+
     if ($self->debug) {
         $self->_rename_to_tmp;
         print STDERR $self->stringify;
@@ -298,7 +298,7 @@ sub _rename_to_tmp {
         for my $name (@output) {
             next NAME if -p $name;
             my $tmp = $self->_tmp_name($name);
-            
+
             $name = $tmp;
         }
         $self->output(\@output);
@@ -309,7 +309,7 @@ sub _rename_to_tmp {
         $self->output($tmp);
     }
     else {
-        _err( 
+        _err(
             "%s is not an accepted output type. It should be impossible to get this error",
             $self->_output_type
         );
@@ -347,7 +347,7 @@ sub _rename_from_tmp {
         $name[-1] =~ s/\.part.+//;
     }
     else {
-        _err( 
+        _err(
             "%s is not an accepted output type. It should be impossible to get this error",
             $self->_output_type
         );
@@ -534,7 +534,7 @@ System::Wrapper - Class-wrapped system calls and qx operator
 
 =head1 VERSION
 
-This document describes System::Wrapper version 0.0.1
+This document describes System::Wrapper version 0.0.2
 
 
 =head1 SYNOPSIS
@@ -567,7 +567,7 @@ This document describes System::Wrapper version 0.0.1
  This module can be used as a generic wrapper around C<system> and C<qx>, or as
  a base class for building interfaces to utilities not available to C<perl> itself.
 
-=head1 INTERFACE 
+=head1 INTERFACE
 
 =head2 CLASS METHODS
 
@@ -597,182 +597,16 @@ This document describes System::Wrapper version 0.0.1
 
 =head2 SELECTOR METHODS
 
-new
-interpreter
-executable
-arguments
-input
-output
-path
-capture
-command
-run
-_program_in_path
-_canonical
-_flatten
-DESTROY
-
-=over
-
-=item server_uri()
-
-=item server_uri($uri)
-
-Default C<$uri>: L<http://api.wordnik.com/api-v3>
-
-
-=item api_key()
-
-=item api_key($key)
-
-Required C<$key>: Your API key, which can be requested at L<http://api.wordnik.com/signup/>.
-
-
-=item version()
-
-=item version($version)
-
-Default C<$version>: I<3>. Only API version 3 (the latest) is currently supported.
-
-
-=item format()
-
-=item format($format)
-
-Default C<$format>: I<json>. Other accepted formats are I<xml> and I<perl>.
-
-
-=item cache()
-
-=item cache($cache)
-
-Default C<$cache>: I<10>. Number of requests to cache. Deletes the oldest request if cache fills up.
-
-
-=item debug()
-
-=item debug($debug)
-
-Default C<$debug>: I<0>. Don't sent GET requests to Wordnik. Return the actual request as a string.
-
-=back
-
-
-=head2 OBJECT METHODS
-
-=over
-
-=item word($word, %args)
-
-This returns the word you requested, assuming it is found in our corpus.
-See L<http://docs.wordnik.com/api/methods#words>.
-
-C<$word> is the word to look up. C<%args> accepts:
-
-Default C<useSuggest>: I<false>. Return an array of suggestions, if available.
-
-Default C<literal>: I<true>. Return non-literal matches.
-
-If the suggester is enabled, you can tell it to return the best match with C<useSuggest=true> and C<literal=false>.
-
-
-=item phrases($word, %args)
-
-You can fetch interesting bi-gram phrases containing a word.
-The "mi" and "wlmi" elements refer to "mutual information" 
-and "weighted mutual information" and will be explained in detail via future blog post.
-See L<http://docs.wordnik.com/api/methods#phrases>.
-
-C<$word> is the word to look up. C<%args> accepts:
-
-Default C<count>: I<5>. Specify the number of results returned.
-
-
-=item definitions($word, %args)
-
-Definitions for words are available from Wordnik's keying of the Century Dictionary and parse of the Webster GCIDE.
-The Dictionary Model XSD is available in L<http://github.com/wordnik/api-examples/blob/master/docs/dictionary.xsd> in GitHub.
-See L<http://docs.wordnik.com/api/methods#definitions>.
-
-C<$word> is the word to look up. C<%args> accepts:
-
-Default C<count>: I<5>. Specify the number of results returned.
-
-Default C<partOfSpeech>: I<empty>. Specify one or many part-of-speech types for which to return definitions. Pass multiple types as an array reference.
-
-The available partOfSpeech values are:
-
-    [noun, verb, adjective, adverb, idiom, article, abbreviation, preposition, prefix, interjection, suffix]
-
-
-=item examples($word)
-
-You can retrieve 5 example sentences for a words in Wordnik's alpha corpus. Each example contains the source document and a source URL, if it exists.
-See L<http://docs.wordnik.com/api/methods#examples>.
-
-C<$word> is the word to look up.
-
-
-=item related($word, %args)
-
-You retrieve related words for a particular word.
-See L<http://docs.wordnik.com/api/methods#relateds>.
-
-C<$word> is the word to look up. C<%args> accepts:
-
-Default C<type>: I<empty>. Return one or many relationship types. Pass multiple types as an array reference.
-
-The available type values are:
-
-    [synonym, antonym, form, equivalent, hyponym, variant]
-
-
-=item frequency($word)
-
-You can see how common particular words occur in Wordnik's alpha corpus, ordered by year.
-See L<http://docs.wordnik.com/api/methods#freq>.
-
-C<$word> is the word to look up.
-
-
-=item punctuationFactor($word)
-
-You can see how common particular words are used with punctuation.
-See L<http://docs.wordnik.com/api/methods#punc>.
-
-C<$word> is the word to look up.
-
-
-=item suggest($word, %args)
-
-The autocomplete service gives you the opportunity to take a word fragment (start of a word) and show what other words start with the same letters.
-The results are based on corpus frequency, not static word lists, so you have access to more dynamic words in the language.
-See L<http://docs.wordnik.com/api/methods#auto>.
-
-C<$word> is the word to look up. C<%args> accepts:
-
-Default C<count>: I<5>. Specify the number of results returned.
-
-Default C<startAt>: I<0>. You can also specify the starting index for the results returned. This allows you to paginate through the matching values.
-
-
-=item wordoftheday
-
-You can fetch Wordnik's word-of-the day which contains definitions and example sentences.
-See L<http://docs.wordnik.com/api/methods#wotd>.
-
-
-=item randomWord(%args)
-
-You can fetch a random word from the Alpha Corpus.
-See L<http://docs.wordnik.com/api/methods#random>.
-
-C<%args> accepts:
-
-Default C<hasDictionaryDef>: I<true>. You can ask the API to return only words where there is a definition available.
-
-=back
-
+ new
+ interpreter
+ executable
+ arguments
+ input
+ output
+ path
+ capture
+ command
+ run
 
 =head1 INSTALLATION
 
@@ -791,52 +625,11 @@ or
    make install
 
 
-=head1 DIAGNOSTICS
-
-=over
-
-=item C<< "Can't access '$key' field in class $class" >>
-
-Private or inexistent member variable.
-
-=item C<< "Invalid argument key or value: '$type'" >>
-
-Inexistent query parameter, or wrong value passed to existing parameter.
-
-=item C<< "Parameter 'partOfSpeech' requires a reference to an array" >>
-
-partOfSpeech => [qw/.../].
-
-=item C<< "Parameter 'type' requires a reference to an array" >>
-
-type => [qw/.../].
-
-=item C<< "The operation you requested requires JSON to be installed" >>
-
-perl -MCPAN -e 'install JSON'.
-
-=item C<< "Unsupported api format: '$format'" >>
-
-Supported formats are 'perl', 'json', 'xml'.
-
-=item C<< "Unsupported api version: '$version'" >>
-
-The only API version supported by this module is 3.
-
-=back
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
 System::Wrapper requires no configuration files or environment variables.
 
 
-=head1 DEPENDENCIES
-
-This module requires the core modules C<Test::More>, C<version> and C<Carp>, and C<LWP::UserAgent> from C<CPAN>.
-Additionally, it recommends-requires C<JSON> from C<CPAN> for getting data in Perl data structures.
-
-
 =head1 INCOMPATIBILITIES
 
 None reported.
@@ -846,37 +639,18 @@ None reported.
 
 No bugs have been reported.
 
-Response headers are not checked for 404s, etc. Likewise, response data is not post-processed in any way, other
-than optionally being parsed from C<JSON> to C<Perl> data structures. Data::Dumper should be of help there.
-
 Please report any bugs or feature requests to
-C<bug-www-wordnik-api@rt.cpan.org>, or through the web interface at
+C<bug-system-wrapper@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
-=head1 TODO
-
-=over
-
-=item Error checking
-
-Implement basic HTTP error checking on response headers.
-
-=item Post-processing
-
-Add filtering methods on response data.
-
-=back
-
-
 =head1 AUTHOR
 
-Pedro Silva  C<< <pedros@berkeley.edu> >>
+Pedro Silva  C<< <psilva+pause@pedrosilva.pt> >>
 
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2010, Pedro Silva C<< <pedros@berkeley.edu> >>. All rights reserved.
+Copyright (c) 2010, Pedro Silva C<< <psilva+pause@pedrosilva.pt> >>. All rights reserved.
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
